# -*- coding: utf-8 -*-


class ElementProcessingError(Exception):
    """
    Raised when a problem is encountered while processing an element
    """

    element_id: str
    """
    ID of the element being processed.
    """

    def __init__(self, element_id: str, *args: object) -> None:
        super().__init__(*args)
        self.element_id = element_id


class ImageDownloadError(ElementProcessingError):
    """
    Raised when an element's image could not be downloaded
    """

    error: Exception
    """
    Error encountered.
    """

    def __init__(self, element_id: str, error: Exception, *args: object) -> None:
        super().__init__(element_id, *args)
        self.error = error

    def __str__(self) -> str:
        return (
            f"Couldn't retrieve image of element ({self.element_id}: {str(self.error)})"
        )
